from email import utils
import datetime
import pycassa
import uuid

configuration = None
try:
    import local_config as configuration
except ImportError:
    pass
if not configuration:
    import configuration

pool = pycassa.ConnectionPool(configuration.cassandra_keyspace, [configuration.cassandra_host])
daybucketscount_cf = pycassa.ColumnFamily(pool, 'DayBucketsCount')
buckets_cf = pycassa.ColumnFamily(pool, 'Buckets')
oops_cf = pycassa.ColumnFamily(pool, 'OOPS')

def get_total_buckets_by_day ():
    """All of the buckets added to for the past seven days."""
    # TODO accept a date range. Client asks for the number of days it can
    # reasonably fit on the screen.
    date = datetime.datetime.utcnow()
    delta = datetime.timedelta(days=1)
    for i in range(7):
        count = daybucketscount_cf.get_count(date.strftime('%Y%m%d'))
        date = (date - delta)
        yield date.strftime('%Y%m%d'), count
    
def get_bucket_counts_for_today (batch_size=100, filter_less_than=5, show_failed=False):
    """The number of times each bucket has been added to today."""
    today = datetime.date.today().strftime('%Y%m%d')
    start = ''
    while True:
        result = daybucketscount_cf.get(today, column_start=start, column_count=100)
        for column, count in result.items():
            if not show_failed and column.startswith('failed'):
                continue
            # These are uninteresting and ubiquitous.
            if count >= filter_less_than:
                yield (column, count)
        # We do not want to include the end of the previous batch.
        start = column + '0'
        if len(result) < 100:
            raise StopIteration

def get_crashes_for_bucket (bucketid, limit=100):
    result = buckets_cf.get(bucketid, column_count=limit).keys()
    return result

def get_package_for_bucket (bucketid):
    '''Returns the first OOPS in the bucket and the package it occurred in.'''

    oopsid = buckets_cf.get(bucketid, column_count=1).keys()[0]
    try:
        return (oopsid, oops_cf.get(oopsid)['Package'].split()[0])
    except KeyError:
        return (oopsid, '')

def get_date_for_oops (oopsid):
    u = uuid.UUID(oopsid)
    u = pycassa.util.convert_uuid_to_time(u)
    # Javascript expects a RF2822 date.
    # TODO just use |date:"r" in template. 
    return utils.formatdate(
        float(datetime.datetime.utcfromtimestamp(u).strftime('%s')))

def get_crash (oopsid):
    return oops_cf.get(oopsid)
